"""
Jax cmd
"""


def main() -> None:
    """
    provide jax cmd for print help info
    Returns:

    """
    print("JAX Tools Commands:")
    print("nd: Check network connectivity")
    print("jax-encrypt: Encrypt and decrypt sensitive information")
